@@ -40,7 +40,7 @@
 #define MSG_USER_OK "Utilisateur %s OK. Veuillez taper votre mot de passe"
 #define MSG_CANT_DO_TWICE "Impossible dans cette session"
 #define MSG_UNABLE_SECURE_ANON "Impossible d'etablir une session FTP anonyme securisee"
-#define MSG_BANDWIDTH_RESTRICTED "La bande-passante est soumise a des quotas"
+#define MSG_BANDWIDTH_RESTRICTED "La bande passante est volontairement restreinte"
 #define MSG_NO_PASSWORD_NEEDED "Pas besoin de mot de passe"
 #define MSG_NOTRUST "Desole, votre compte est inutilisable"
 #define MSG_WHOAREYOU "Qui etes vous ?"
@@ -173,18 +173,17 @@
 #define MSG_WELCOME_TO "Bienvenue sur"
 #define MSG_MAX_USERS "%lu utilisateurs (le maximum) sont deja connectes, desole"
 #define MSG_NB_USERS "Vous etes l'utilisateur %d sur les %d autorises."
-#define MSG_WELCOME_TIME "L'heure locale est %02d:%02d et la charge courante est de %3.2f. Port : %u."
+#define MSG_WELCOME_TIME "L'heure locale est %02d:%02d. Port du serveur : %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Seules les connexions anonymes sont acceptees"
 #define MSG_RATIOS_EVERYONE "LES RATIOS SONT ACTIVES POUR TOUS LES UTILISATEURS :"
 #define MSG_RATIOS_ANONYMOUS "LES UTILISATEURS ANONYMES SONT SUJETS A DES RATIOS DE UL/DL :"
 #define MSG_RATIOS_RULE "Pour downloader %u Mo, vous devez uploader %u Mo."
 #define MSG_INFO_IDLE_M "Vous serez deconnectes apres %lu minutes d'inactivite."
 #define MSG_INFO_IDLE_S "Vous serez deconnectes apres %lu secondes d'inactivite."
-#define MSG_INFO_CPU_TIME "Deloggue - Temps CPU utilise : %ld.%03ld secondes."
 #define MSG_CANT_READ_FILE "Impossible de lire [%s]"
 #define MSG_LS_TRUNCATED "Sortie tronquee a %u elements"
 #define MSG_LS_SUCCESS "%u elements au total"
-#define MSG_LOGOUT "Deloggue"
+#define MSG_LOGOUT "Deloggue."
 #define MSG_AUTH_FAILED_LOG "Erreur d'authentification pour l'utilisateur [%s]"
 #define MSG_ILLEGAL_UMASK "Umask invalide"
 #define MSG_STANDALONE_FAILED "Impossible de demarrer le serveur en standalone"
