@@ -173,18 +173,17 @@
 #define MSG_WELCOME_TO "C'est de la bonne :"
 #define MSG_MAX_USERS "%lu relous (le maximum) sont deja connectes, degage"
 #define MSG_NB_USERS "T'es le numero %d sur les %d max."
-#define MSG_WELCOME_TIME "L'heure locale est %02d:%02d et la charge courante est de %3.2f. Port : %u."
+#define MSG_WELCOME_TIME "L'heure locale est %02d:%02d. Port du serveur : %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Je prend que les mecs anonymes"
 #define MSG_RATIOS_EVERYONE "Y A DES RATIOS POUR TOUS LES UTILISATEURS :"
 #define MSG_RATIOS_ANONYMOUS "LES UTILISATEURS ANONYMES ONT DES RATIOS DE UL/DL :"
 #define MSG_RATIOS_RULE "Pour leecher %u Mo, tu dois balancer %u Mo."
 #define MSG_INFO_IDLE_M "Si tu pionces plus de %lu minutes, tu te fais tej."
 #define MSG_INFO_IDLE_S "Si tu pionces plus de %lu secondes tu te fais tej."
-#define MSG_INFO_CPU_TIME "C'est ca, casse-toi. T'as deja bouffe %ld.%03ld s de CPU."
 #define MSG_CANT_READ_FILE "[%s] il suce des bites en enfer"
 #define MSG_LS_TRUNCATED "Je t'en file %u et c'est deja pas mal"
 #define MSG_LS_SUCCESS "%u elements, y a de la stuff"
-#define MSG_LOGOUT "Cassos"
+#define MSG_LOGOUT "Cassos."
 #define MSG_AUTH_FAILED_LOG "[%s] c'est un batard, il connait pas son code"
 #define MSG_ILLEGAL_UMASK "Umask pourrave"
 #define MSG_STANDALONE_FAILED "Le serveur en standalone ? Tu reves."
